==> nextcloud-app-calendar-1%3A5.5.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/mn.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s хэрэглэгч »%s« календарийг нийтлэв",
    "Hello," : "Сайн байна уу",
    "We wanted to inform you that %s has published the calendar »%s«." : "%s хэрэглэгч нь  »%s« календарийг нийтэлснийг үүгээр мэдэгдэе.",
    "Open »%s«" : "»%s« нээх",
    "Cheers!" : "Болж байна!",
    "Upcoming events" : "Удахгүй болох үйл явдлууд",
    "Calendar" : "Календарь",
    "Confirm" : "Батлах",
    "This confirmation link expires in %s hours." : "Энэ баталгаажуулах холбоос %s цагийн дараа дуусна ",
    "Date:" : "Огноо:",
    "Where:" : " Хаана:",
    "Location:" : "Байршил:",
    "A Calendar app for Nextcloud" : "Нэкстклауд Календарь апп ",
    "Previous day" : "Өмнөх өдөр",
    "Previous week" : "Өнмөх 7 хоног",
    "Previous month" : "Өмнөх сар",
    "Next day" : "Маргааш",
    "Next week" : "Дараа 7 хоног",
    "Next month" : "Дараа сар",
    "Today" : "Өнөөдөр",
    "Day" : "Өдөр",
    "Week" : "Долоо хоног",
    "Month" : "Сар",
    "List" : "Жагсаалт",
    "Preview" : "шалгах",
    "Copy link" : "Холбоос хуулах",
    "Edit" : "засварлах",
    "Delete" : "Устгах",
    "Disable calendar \"{calendar}\"" : "Кадендарь Идэвхигүй болгох \"{calendar}\"",
    "Shared with you by" : "Таньд хуваалцсан",
    "Edit and share calendar" : " Календарь засварлах болон хуваалцах",
    "Edit calendar" : "Календар засварлах",
    "Add new" : "Шинээр нэмэх",
    "New calendar" : "Шинэ цагийн хуваарь",
    "Export" : "Экспорт",
    "Name" : "Нэр",
    "Deleted" : "Устгагдсан",
    "Restore" : "Сэргээх",
    "Delete permanently" : "бүр мөсөн устгах",
    "Deck" : "Ажлын талбар",
    "Hidden" : "Далд",
    "Share link" : "Холбоос хуваалцах",
    "can edit" : "засаж чадна",
    "Share with users or groups" : "Бусад хэрэглэгч, бүлэгт хуваалцах",
    "Save" : "Хадгалах",
    "Filename" : "Файлын нэр",
    "Cancel" : "Цуцлах",
    "Actions" : "Үйл ажиллагаа",
    "Show week numbers" : "7 хоногийн дугаарыг харуулах",
    "Update" : "Шинэчлэх",
    "Location" : "Байршил",
    "Description" : "Тодорхойлолт",
    "to" : "Дуусах нь",
    "Add" : "нэмэх",
    "Monday" : "даваа",
    "Tuesday" : "мягмар",
    "Wednesday" : "лхагва",
    "Thursday" : "пүрэв",
    "Friday" : "баасан",
    "Saturday" : "бямба",
    "Sunday" : "ням гариг",
    "Back" : "Буцах",
    "Notification" : "Мэдэгдэл",
    "Email" : "Цахим шуудан",
    "seconds" : "секунд",
    "hours" : "хугацаа",
    "days" : "өдрүүд",
    "Delete file" : "Файл устгах",
    "Available" : "Боломжтой",
    "Unknown" : "Үл танигдах зүйл",
    "Accept" : "Хүлээн зөвшөөрөх",
    "Decline" : "Зөвшөөрөхгүй",
    "Tentative" : "Урьдчилсан тов",
    "Attendees" : "Оролцогчид",
    "Repeat" : "Давтах",
    "never" : "хэзээ ч үгүй",
    "after" : "дараа",
    "Create" : "үүсгэх",
    "Global" : "Нийтийн",
    "Subscribe" : "Захиалга",
    "Personal" : "Хувийн",
    "Edit event" : "Үйл явдлыг засварлах",
    "Close" : "Хаах",
    "Week {number} of {year}" : "{year} оны {number}-р долоо хоног ",
    "Daily" : "Өдөр бүр",
    "Weekly" : "Долоо хоног бүр",
    "Other" : "Бусад",
    "When shared show full event" : "Түгээсэн тохиолдолд үйл явдлыг бүтнээр нь харуул",
    "When shared show only busy" : "Түгээсэн тохиолдолд зөвхөн завгүй гэж харуул",
    "When shared hide this event" : "Түгээсэн тохиолдолд энэ үйл явдлыг нуу",
    "Status" : "төлөв",
    "Confirmed" : "Баталгаажсан",
    "Categories" : "төрөл"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1%3A6.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/mn.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s хэрэглэгч »%s« календарийг нийтлэв",
    "Hello," : "Сайн байна уу",
    "We wanted to inform you that %s has published the calendar »%s«." : "%s хэрэглэгч нь  »%s« календарийг нийтэлснийг үүгээр мэдэгдэе.",
    "Open »%s«" : "»%s« нээх",
    "Cheers!" : "Болж байна!",
    "Upcoming events" : "Удахгүй болох үйл явдлууд",
    "Calendar" : "Календарь",
    "Confirm" : "Батлах",
    "This confirmation link expires in %s hours." : "Энэ баталгаажуулах холбоос %s цагийн дараа дуусна ",
    "Date:" : "Огноо:",
    "Where:" : " Хаана:",
    "Location:" : "Байршил:",
    "A Calendar app for Nextcloud" : "Нэкстклауд Календарь апп ",
    "Previous day" : "Өмнөх өдөр",
    "Previous week" : "Өнмөх 7 хоног",
    "Previous month" : "Өмнөх сар",
    "Next day" : "Маргааш",
    "Next week" : "Дараа 7 хоног",
    "Next month" : "Дараа сар",
    "Today" : "Өнөөдөр",
    "Day" : "Өдөр",
    "Week" : "Долоо хоног",
    "Month" : "Сар",
    "List" : "Жагсаалт",
    "Preview" : "шалгах",
    "Copy link" : "Холбоос хуулах",
    "Edit" : "засварлах",
    "Delete" : "Устгах",
    "Disable calendar \"{calendar}\"" : "Кадендарь Идэвхигүй болгох \"{calendar}\"",
    "Shared with you by" : "Таньд хуваалцсан",
    "Edit and share calendar" : " Календарь засварлах болон хуваалцах",
    "Edit calendar" : "Календар засварлах",
    "Add new" : "Шинээр нэмэх",
    "New calendar" : "Шинэ цагийн хуваарь",
    "Export" : "Экспорт",
    "Name" : "Нэр",
    "Deleted" : "Устгагдсан",
    "Restore" : "Сэргээх",
    "Delete permanently" : "бүр мөсөн устгах",
    "Deck" : "Ажлын талбар",
    "Share link" : "Холбоос хуваалцах",
    "can edit" : "засаж чадна",
    "Share with users or groups" : "Бусад хэрэглэгч, бүлэгт хуваалцах",
    "Save" : "Хадгалах",
    "Filename" : "Файлын нэр",
    "Cancel" : "Цуцлах",
    "Actions" : "Үйл ажиллагаа",
    "General" : "ерөнхий",
    "Show week numbers" : "7 хоногийн дугаарыг харуулах",
    "Update" : "Шинэчлэх",
    "Location" : "Байршил",
    "Description" : "Тодорхойлолт",
    "to" : "Дуусах нь",
    "Add" : "нэмэх",
    "Monday" : "даваа",
    "Tuesday" : "мягмар",
    "Wednesday" : "лхагва",
    "Thursday" : "пүрэв",
    "Friday" : "баасан",
    "Saturday" : "бямба",
    "Sunday" : "ням гариг",
    "Back" : "Буцах",
    "Notification" : "Мэдэгдэл",
    "Email" : "Цахим шуудан",
    "seconds" : "секунд",
    "hours" : "хугацаа",
    "days" : "өдрүүд",
    "Delete file" : "Файл устгах",
    "Available" : "Боломжтой",
    "Unknown" : "Үл танигдах зүйл",
    "Accept" : "Хүлээн зөвшөөрөх",
    "Decline" : "Зөвшөөрөхгүй",
    "Tentative" : "Урьдчилсан тов",
    "Attendees" : "Оролцогчид",
    "Repeat" : "Давтах",
    "never" : "хэзээ ч үгүй",
    "after" : "дараа",
    "None" : "юу ч үгүй",
    "Create" : "үүсгэх",
    "Global" : "Нийтийн",
    "Subscribe" : "Захиалга",
    "Personal" : "Хувийн",
    "Edit event" : "Үйл явдлыг засварлах",
    "Close" : "Хаах",
    "Submit" : "мэдэгдэх",
    "Week {number} of {year}" : "{year} оны {number}-р долоо хоног ",
    "Daily" : "Өдөр бүр",
    "Weekly" : "Долоо хоног бүр",
    "Other" : "Бусад",
    "When shared show full event" : "Түгээсэн тохиолдолд үйл явдлыг бүтнээр нь харуул",
    "When shared show only busy" : "Түгээсэн тохиолдолд зөвхөн завгүй гэж харуул",
    "When shared hide this event" : "Түгээсэн тохиолдолд энэ үйл явдлыг нуу",
    "Status" : "төлөв",
    "Confirmed" : "Баталгаажсан",
    "Categories" : "төрөл",
    "Hidden" : "Далд"
},
"nplurals=2; plural=(n != 1);");
